@@ -1,20 +1,31 @@
 
-# Use Audiere (http://audiere.sf.net) in Perl
+# Audiere (http://audiere.sf.net) in Perl (C) by Tels <http://bloodgate.com/>
 
 package Audio::Audiere;
 
-# (C) by Tels <http://bloodgate.com/>
-
 use strict;
-
 require Exporter;
 
 use vars qw/@ISA $VERSION @EXPORT_OK/;
 @ISA = qw/Exporter/;
 
-@EXPORT_OK = qw/AUDIO_STREAM AUDIO_BUFFER/;
+@EXPORT_OK = qw/
+  AUDIO_STREAM AUDIO_BUFFER
+    FF_AUTODETECT
+    FF_WAV
+    FF_OGG
+    FF_FLAC
+    FF_MP3
+    FF_MOD
+    FF_AIFF
+    SF_U8
+    SF_S16
+  /;
 
-$VERSION = '0.03';
+$VERSION = '0.04';
+
+# a package to have Audiere_perl.dll under Win32, to avoid clash with the
+# Audiere.dll
 
 package Audio::Audiere::Audiere_perl;
 
@@ -26,22 +37,38 @@ bootstrap Audio::Audiere::Audiere_perl $Audio::Audiere::VERSION;
 
 package Audio::Audiere;
 
-#use Audio::Audiere::Audiere_perl;	# load our .so/.dll object
 use Audio::Audiere::Stream;
 
 use constant AUDIO_STREAM => 0;
 use constant AUDIO_BUFFER => 1;
 
+# enum FileFormat
+
+use constant FF_AUTODETECT => 0;
+use constant FF_WAV => 1;
+use constant FF_OGG => 2;
+use constant FF_FLAC => 3;
+use constant FF_MP3 => 4;
+use constant FF_MOD => 5;
+use constant FF_AIFF => 6;
+  
+# enum SampleFormat
+
+use constant SF_U8 => 0;
+use constant SF_S16 => 1;
+
 ##############################################################################
 
 sub new
   {
-  # create a new instance of Audio::Audiere - there can be only one
+  # create a new instance of Audio::Audiere
   my $class = shift;
   my $self = {}; bless $self, $class;
 
   $self->{error} = '';
-  if (!$self->_init_device( $_[0] || '', $_[1] || '' ))
+  $self->{_device} = $self->_init_device( $_[0] || '', $_[1] || '');
+
+  if (!$self->{_device})
     {
     return
       Audio::Audiere::Error->new("Could not init device '$_[0]'");
@@ -54,7 +81,7 @@ sub DESTROY
   {
   my $self = shift;
 
-  $self->_drop_device();
+  $self->_drop_device($self->{_device}) if $self->{_device};
   }
 
 sub error
@@ -70,31 +97,38 @@ sub addStream
   {
   my $self = shift;
 
-  Audio::Audiere::Stream->new(@_);
+  Audio::Audiere::Stream->new($self->{_device},@_);
+  }
+
+sub addStream3D
+  {
+  my $self = shift;
+
+  Audio::Audiere::Stream::3D->new($self->{_device},@_);
   }
 
 sub addTone
   {
   my $self = shift;
-  Audio::Audiere::Stream->tone(@_);
+  Audio::Audiere::Stream->tone($self->{_device},@_);
   }
 
 sub addSquareWave
   {
   my $self = shift;
-  Audio::Audiere::Stream->square_wave(@_);
+  Audio::Audiere::Stream->square_wave($self->{_device},@_);
   }
 
 sub addWhiteNoise
   {
   my $self = shift;
-  Audio::Audiere::Stream->white_noise();
+  Audio::Audiere::Stream->white_noise($self->{_device});
   }
 
 sub addPinkNoise
   {
   my $self = shift;
-  Audio::Audiere::Stream->pink_noise();
+  Audio::Audiere::Stream->pink_noise($self->{_device});
   }
 
 sub dropStream
@@ -103,6 +137,13 @@ sub dropStream
   # TODO: streams are not registered, so nothing to do now
   }
 
+sub getName
+  {
+  my $self = shift;
+
+  _get_name($self->{_device});
+  }
+
 1; # eof
 
 __END__
@@ -156,13 +197,24 @@ Audio::Audiere - use the Audiere sound library in Perl
 	
  	$sound->play();			# start playing
 
-	# free sound device (not neccessary, will be done automatically)
-	# $driver = undef;
+	# free sound device is not neccessary, will be done automatically
 
 =head1 EXPORTS
 
-Exports nothing on default. Can export C<AUDIO_BUFFER> and C<AUDIO_STREAM>
-on request.
+Exports nothing on default. Can export C<AUDIO_BUFFER> and C<AUDIO_STREAM>,
+as well as the following constants for file formats:
+
+	FF_AUTODETECT
+	FF_WAV
+	FF_OGG
+	FF_FLAC
+	FF_MP3
+	FF_MOD
+
+Also, the following sample source format constants can be exported:
+
+	SF_U8
+	SF_S16
 
 =head1 DESCRIPTION
 
@@ -185,25 +237,33 @@ When C<$audiere> goes out of scope or is set to undef, the device will
 be automatically released.
 
 In case you wonder how you can play multiple sounds at once with only once
-device: these are handled as separate streams, and once you have the Audiere
-driver, you can add (almost infinitely) many of them via L<addStream> (or
+device: these are handled as separate streams, and once you have the device,
+you can add (almost infinitely) many of them via L<addStream> (or
 any of the other C<add...()> methods.
 
+In theory you can open more than one device, however, in praxis usually only
+one of them is connected to the sound output, so this does not make much sense.
+
 =item getVersion
+	
+	print $audiere->getVersion();
 
 Returns the version of Audiere you are using as string.
 
 =item getName
 
+	print $audiere->getName();
+
 Returns the name of the audio device, like 'oss' or 'directsound'.
 
 =item addStream
 
 	$stream = $audiere->addStream( $file, $stream_flag )
 
-Create a new sound stream object, and return it. See L<METHODS ON STREAMS>
-on what methods you can use to manipulate the stream object. Most popular
-will be C<play()>, of course :)
+Create a new sound stream object from C<$file>, and return it.
+
+See L<METHODS ON STREAMS> on what methods you can use to manipulate the stream
+object. Most popular will be C<play()>, of course :)
 
 You should always check for errors before using the stream object:
 	
@@ -218,7 +278,7 @@ You should always check for errors before using the stream object:
 
 Create a stream object that produces a tone at the given C<$frequenzy>.
 
-See also L<addStream> and L<Methods on streams>.
+See also L<addStream> and L<Audio::Audiere::Stream>.
 
 =item addSquareWave
 
@@ -226,7 +286,7 @@ See also L<addStream> and L<Methods on streams>.
 
 Create a stream object that produces a swaure wave at the given C<$frequenzy>.
 
-See also L<addStream> and L<Methods on streams>.
+See also L<addStream> and L<Audio::Audiere::Stream>.
 
 =item addWhiteNoise
 
@@ -234,7 +294,7 @@ See also L<addStream> and L<Methods on streams>.
 
 Create a stream object that produces white noise.
 
-See also L<addStream> and L<Methods on streams>.
+See also L<addStream> and L<Audio::Audiere::Stream>.
 
 =item addPinkNoise
 
@@ -243,7 +303,7 @@ See also L<addStream> and L<Methods on streams>.
 Create a stream object that produces pink noise, which is noise with an equal
 power distribution among octaves (logarithmic), not frequencies.
 
-See also L<addStream> and L<Methods on streams>.
+See also L<addStream> and L<Audio::Audiere::Stream>.
 
 =item dropStream
 
@@ -259,90 +319,14 @@ can also do it like this or just have C<$stream> go out of scope:
 	$second_stream = $audiere->dupeStream($stream);
 	$second_stream = $stream->copy();
 
-=back
-
-=head2 METHODS ON STREAMS
-
-Methods on streamds must be called on stream objects that are returned by
-L<addStream>.
-
-=over 2
-
-=item error
-
-	if ($stream->error())
-	  {
-	  print "Fatal error: ", $stream->error(),"\n";
-	  }
-
-Return the last error message, or undef for no error.
-
-=item play
-
-Start playing the stream.
-
-=item stop
-
-Stop playing the stream.
-
-=item isSeekable
-
-=item getLength
-
-=item isPlaying
-
-	while ($stream->isPlaying())
-	  {
-	  ...
-	  }
-
-Returns true if the stream still plays.
-
-=item getPosition
-
-=item getFormat
-
-=item getSamples
-
-=item getVolume
-
-Returns the volume of the stream as a value between 0 and 1.
-
-=item setVolume
-
-Set the volume of the stream as a value between 0 and 1.
-
-=item getRepeat
-
-Returns true if the stream is repeating (aka looping).
-
-=item setRepeat
-
-	$stream->setRepeat(1);		# loop
-	$stream->setRepeat(0);		# don't loop
-
-If true, the stream will repeat (aka loop).
-
-=item setPan
-
-	$stream->setPan ( -1.0 );	# -1.0 = left, 0 = center, 1.0 = right
-
-Set the panning of the sound from -1.0 to +1.0.
-
-=item getPan
-
-Returns the current panning of the sound from -1.0 to +1.0. See L<setPan>.
-
-=item setPitch
-
-=item getPitch
-
-=item setPitchShift
-
-=item getPosition
+Create a copy of a stream. The streams will share the memory for the sound
+data, but have separate volumes, positions, pan etc.
 
 =back
 
+See L<Audio::Audiere::Stream> for a list of methods you can call on sound
+streams.
+
 =head1 AUTHORS
 
 (c) 2004 Tels <http://bloodgate.com/>
